@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Patch.py 11432 2019-04-10 06:04:43Z Lavender $
+# $Id: Patch.py 11450 2019-04-13 13:56:11Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-04-10 15:04:43 +0900 (週三, 10 四月 2019) $
-# $Revision: 11432 $
+# $Date: 2019-04-13 22:56:11 +0900 (週六, 13 四月 2019) $
+# $Revision: 11450 $
 #
 # Contributors:
 #  Bear
@@ -33,7 +33,7 @@ except ImportError:
  
 def patterns(prefix, *args): 
     if DJANGO_VERSION >= 210: # django >= 1.11
-        return args
+        return list(args)
     else:
         from django.conf.urls import patterns as _patterns
         
@@ -232,11 +232,19 @@ def attachURLs(settings, urlpatterns):
     )
 
     if settings.DEBUG == False and settings.SERVER_MODE == settings.DEVELOPMENT:
-        urlpatterns += patterns('',
-            url(r'^media/(?P<path>.*)$', 'django.views.static.serve', {
-                'document_root': settings.MEDIA_ROOT,
-            })
-    )
+        if DJANGO_VERSION >= 210: # django >= 1.11
+            from django.views.static import serve
+            urlpatterns += patterns('',
+                url(r'^media/(?P<path>.*)$', serve, {
+                    'document_root': settings.MEDIA_ROOT,
+                })
+            )
+        else:
+            urlpatterns += patterns('',
+                url(r'^media/(?P<path>.*)$', 'django.views.static.serve', {
+                    'document_root': settings.MEDIA_ROOT,
+                })
+            )
 
 # http://www.arthurkoziel.com/2009/01/15/
 # passing-mediaurl-djangos-500-error-view/
