@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Util.py 11435 2019-04-10 13:43:34Z Lavender $
+# $Id: Util.py 11452 2019-04-13 15:00:15Z Andy $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2019-04-10 22:43:34 +0900 (週三, 10 四月 2019) $
-# $Revision: 11435 $
+# $Author: Andy $ (last)
+# $Date: 2019-04-14 00:00:15 +0900 (週日, 14 四月 2019) $
+# $Revision: 11452 $
 
 import sys
 import six
@@ -23,7 +23,7 @@ import urllib
 from collections import OrderedDict
 
 from django.conf import settings
-
+from Iuno import DJANGO_VERSION
 if sys.version_info.major == 3:
     from urllib.parse import urlencode
 else:
@@ -101,21 +101,34 @@ class CathaybkAPI(object):
 
     def buildXml(self, data):
         temp = get_template('shop/payment/Cathaybk.xml')
-        context = Context({
-            'data': data,
-            'checkValue': self.generateCheckValue(data),
-            'merchantId': self.merchantId,
-        })
+        if DJANGO_VERSION >= 210: # django >= 1.11
+            context = {
+                'data': data,
+                'checkValue': self.generateCheckValue(data),
+                'merchantId': self.merchantId,
+            }
+        else:
+            context = Context({
+                'data': data,
+                'checkValue': self.generateCheckValue(data),
+                'merchantId': self.merchantId,
+            })
         xml = temp.render(context)
         return xml
 
     def buildForm(self, data):
         xml = self.buildXml(data)
         temp = get_template('shop/payment/Cathaybk.html')
-        context = Context({
-            'xml': xml,
-            'apiUrl': CATHAPBK_SERVICE_URL,
-        })
+        if DJANGO_VERSION >= 210: # django >= 1.11
+            context = {
+                'xml': xml,
+                'apiUrl': CATHAPBK_SERVICE_URL,
+            }
+        else:
+            context = Context({
+                'xml': xml,
+                'apiUrl': CATHAPBK_SERVICE_URL,
+            })
         form = temp.render(context)
         return form
         
