@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11442 2019-04-12 12:01:47Z Lavender $
+# $Id: __init__.py 11452 2019-04-13 15:00:15Z Andy $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2019-04-12 21:01:47 +0900 (週五, 12 四月 2019) $
-# $Revision: 11442 $
+# $Author: Andy $ (last)
+# $Date: 2019-04-14 00:00:15 +0900 (週日, 14 四月 2019) $
+# $Revision: 11452 $
 
 import os
 import sys
@@ -717,8 +717,10 @@ def buildAPIForm(submission, request, apiName, extra={}):
         )
 
         payment = mpg.createPayment(data)
-        context = Context({'spgateway': payment,})
-
+        if DJANGO_VERSION >= 210: # django >= 1.11
+            context = {'spgateway': payment,}
+        else:
+            context = Context({'spgateway': payment,})
         temp = get_template('shop/payment/Spgateway.html')
         form = temp.render(context)
                                       
@@ -922,10 +924,17 @@ def buildAPIForm(submission, request, apiName, extra={}):
         data["CheckMacValue"] = checkValue
 
         temp = get_template('shop/payment/EcpayLogistic.html')
-        context = Context({
-            'apiUrl': apiUrl,
-            'data': data,
-        })
+        if DJANGO_VERSION >= 210: # django >= 1.11
+            print("jiji")
+            context = {
+                'apiUrl': apiUrl,
+                'data': data,
+            }
+        else:
+            context = Context({
+                'apiUrl': apiUrl,
+                'data': data,
+            })
         form = temp.render(context)
 
         return form
