@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11348 2019-01-21 18:14:25Z Lavender $
+# $Id: views.py 11442 2019-04-12 12:01:47Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,13 +12,14 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-01-22 03:14:25 +0900 (週二, 22 一月 2019) $
-# $Revision: 11348 $ 
+# $Date: 2019-04-12 21:01:47 +0900 (週五, 12 四月 2019) $
+# $Revision: 11442 $ 
 
 import json
 import logging
 import hashlib
 import urllib
+import six
 
 from collections import OrderedDict
 
@@ -42,10 +43,11 @@ from django.template import Context
 from django.db.models import Q
 from paypal.express.views import SuccessResponseView
 from oscar.core.loading import get_model, get_class
-from oscar.core.phonenumber import to_python
+from phonenumber_field.phonenumber import to_python
 from oscar.core.compat import get_user_model
 
 from Iuppiter.Encoding import utf8
+from Iuno import DJANGO_VERSION
 from Iuno.shop import forms
 from Iuno.shop import buildAPIForm
 from Iuno.shop.models import (
@@ -87,7 +89,11 @@ class SuccessResponseView(SuccessResponseView):
 from oscar.apps.checkout import views
 from oscar.apps.dashboard.orders.views import OrderListView
 from oscar.core.compat import UnicodeCSVWriter
-from django.utils.datastructures import SortedDict
+
+if DJANGO_VERSION >= 190: # django >= 1.9.0
+    from collections import OrderedDict as SortedDict
+else:
+    from django.utils.datastructures import SortedDict
 from oscar.core.utils import format_datetime
 
 def get_context_data(self, **kwargs):
@@ -194,8 +200,11 @@ def download_selected_orders(self, request, orders):
         else:
             row['billing_address_name'] = ''
         writer.writerow(row.values())
-        
-    response.content = '\xEF\xBB\xBF' + response.content
+      
+    if six.PY3:
+        response.content = '\xEF\xBB\xBF' + response.content.decode('utf8')
+    else:
+        response.content = '\xEF\xBB\xBF' + response.content
     
     return response
 
@@ -454,7 +463,11 @@ class SuccessResponseView2(_PaymentDetailsView):
                                 request.POST.get('MerchantTradeNo')[index + 8:])
 
                 # error
-                if self.rtnMsg == 'ERROR':
+                if self.apiName == ALLPAY:
+                    result = not str(self.rtnCode) == str(0)
+                else:
+                    result = self.rtnMsg == 'ERROR'
+                if result:
                     msg = _(
                         "There was an error in the payment. Please try again.")
                     messages.error(self.request, msg)
