@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: AttachSettingsTest.py 11172 2018-07-16 09:31:00Z Lavender $
+# $Id: AttachSettingsTest.py 11430 2019-04-10 05:13:37Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,16 +12,32 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-07-16 18:31:00 +0900 (週一, 16 七月 2018) $
-# $Revision: 11172 $
+# $Date: 2019-04-10 14:13:37 +0900 (週三, 10 四月 2019) $
+# $Revision: 11430 $
 
 import os
+import warnings
 
 from django.test import TestCase
 
 from Iuno import member
 
 BASE_DIR = '.'
+
+try:
+    import django
+
+    DJANGO_VERSION = (django.VERSION[0] * 100 + django.VERSION[1] * 10 +
+                      django.VERSION[2])
+                      
+    if DJANGO_VERSION >= 210: # django >= 1.11
+        MIDDLEWARE = 'MIDDLEWARE'
+    else:
+        MIDDLEWARE = 'MIDDLEWARE_CLASSES'
+        
+except ImportError:
+    warnings.warn("Unable to import django, many Iuno packages require it.")
+    
 class TestAttachSettings(TestCase):
     
     def testSettingsContent(self):
@@ -37,7 +53,7 @@ class TestAttachSettings(TestCase):
                 'django.contrib.messages',
                 'django.contrib.staticfiles',
             ),
-            'MIDDLEWARE_CLASSES' : (
+            MIDDLEWARE : (
                 'django.contrib.sessions.middleware.SessionMiddleware',
                 'django.middleware.common.CommonMiddleware',
                 'django.middleware.csrf.CsrfViewMiddleware',
@@ -88,7 +104,7 @@ class TestAttachSettings(TestCase):
                 'django.contrib.messages',
                 'django.contrib.staticfiles',
             ),
-            'MIDDLEWARE_CLASSES' : (
+            MIDDLEWARE : (
                 'django.contrib.sessions.middleware.SessionMiddleware',
                 'django.middleware.common.CommonMiddleware',
                 'django.middleware.csrf.CsrfViewMiddleware',
